#ifndef __YKEY_H
#define __YKEY_H

#include "ylib.h"

#include <X11/XKBlib.h>
#include <X11/keysym.h>

#endif

// vim: set sw=4 ts=4 et:
